import * as i0 from '@angular/core';
import { Injectable, InjectionToken, Optional, Inject, NgModule } from '@angular/core';
import { HttpResponse, HttpHeaders, HttpErrorResponse, HttpBackend } from '@angular/common/http';
import * as i2 from '@nativescript/angular';
import { NsHttpBackEnd, NativeScriptHttpClientModule } from '@nativescript/angular';
import { request, enableSSLPinning } from '@nativescript-community/https';
import { throwError, from } from 'rxjs';
import { map, catchError } from 'rxjs/operators';
import * as i1 from '@angular/common';

class ExcludedService {
    _urlList = [];
    static isMultipartFormRequest(request) {
        const headers = request.headers.get('Content-Type');
        return headers ? headers.includes('application/x-www-form-urlencoded') : false;
    }
    addUrl(domain) {
        this._urlList.push(domain);
    }
    contains(needle) {
        return Boolean(this._urlList.filter((url) => url === needle).length);
    }
    skipSslPinning(request) {
        return this.contains(request.url);
    }
    static ɵfac = function ExcludedService_Factory(t) { return new (t || ExcludedService)(); };
    static ɵprov = /*@__PURE__*/ i0.ɵɵdefineInjectable({ token: ExcludedService, factory: ExcludedService.ɵfac });
}
(() => { (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassMetadata(ExcludedService, [{
        type: Injectable
    }], null, null); })();

/** Page size injection token. */
const HTTPS_REQUEST_DEFAULT_OPTIONS = new InjectionToken('HTTPS_REQUEST_DEFAULT_OPTIONS');
class NativeScriptHttpXhrBackend extends NsHttpBackEnd {
    _excludedService;
    _defaults;
    constructor(xhrFactory, nsFileSystem, _excludedService, _defaults) {
        super(xhrFactory, nsFileSystem);
        this._excludedService = _excludedService;
        this._defaults = _defaults;
    }
    handle(req) {
        let result;
        if (this._isLocalRequest(req.url) || this._excludedService.skipSslPinning(req)) {
            result = super.handle(req);
        }
        else {
            result = this._request(req).pipe(map((response) => {
                if (response.statusCode < 200 || response.statusCode > 299) {
                    throw this._mapHttpErrorResponse(response, req);
                }
                return new HttpResponse({
                    body: response.content,
                    headers: new HttpHeaders(response.headers),
                    status: response.statusCode,
                    statusText: response.reason,
                    url: req.url
                });
            }), catchError((error) => throwError(() => error)));
        }
        return result;
    }
    _isLocalRequest(url) {
        return url.indexOf('~') === 0 || url.indexOf('/') === 0;
    }
    _request(request$1) {
        const method = request$1.method;
        let url = request$1.url;
        if (request$1.params) {
            const params = request$1.params.toString();
            if (params.length) {
                const qIdx = url.indexOf('?');
                const sep = qIdx === -1 ? '?' : (qIdx < url.length - 1 ? '&' : '');
                url += sep + params;
            }
        }
        return from(request({
            url,
            method,
            headers: this._mapHeaders(request$1),
            params: this._mapParams(request$1),
            body: request$1.body,
            timeout: this._defaults?.timeout ?? 3 * 60,
            allowLargeResponse: this._defaults?.allowLargeResponse ?? true,
            cachePolicy: this._defaults?.cachePolicy ?? 'noCache',
            cookiesEnabled: this._defaults?.cookiesEnabled ?? false
        }, this._defaults?.useLegacy ?? true));
    }
    _mapHeaders(request) {
        const headerKeys = request.headers.keys();
        const headers = headerKeys.reduce((accumulator, key) => {
            const values = request.headers.getAll(key);
            if (values !== null && values !== undefined) {
                accumulator[key] = values.length > 1 ? values.join(' ') : values[0];
            }
            return accumulator;
        }, {});
        if (Object.keys(headers).length) {
            return headers;
        }
        return {
            'Content-Type': 'application/json',
            Accept: 'application/json'
        };
    }
    _mapParams(request) {
        const paramKeys = request.params.keys();
        const params = paramKeys.reduce((accumulator, key) => {
            const values = request.params.getAll(key);
            if (values !== null && values !== undefined) {
                accumulator[key] = values.length > 1 ? values : values[0];
            }
            return accumulator;
        }, {});
        return params;
    }
    _mapHttpErrorResponse(error, request) {
        return new HttpErrorResponse({
            error: error.content,
            status: error.statusCode,
            headers: new HttpHeaders(error.headers),
            statusText: error.reason || (typeof error.content === 'string' && error.content) || String(error.statusCode),
            url: request.url
        });
    }
    static ɵfac = function NativeScriptHttpXhrBackend_Factory(t) { return new (t || NativeScriptHttpXhrBackend)(i0.ɵɵinject(i1.XhrFactory), i0.ɵɵinject(i2.NSFileSystem), i0.ɵɵinject(ExcludedService), i0.ɵɵinject(HTTPS_REQUEST_DEFAULT_OPTIONS, 8)); };
    static ɵprov = /*@__PURE__*/ i0.ɵɵdefineInjectable({ token: NativeScriptHttpXhrBackend, factory: NativeScriptHttpXhrBackend.ɵfac });
}
(() => { (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassMetadata(NativeScriptHttpXhrBackend, [{
        type: Injectable
    }], () => [{ type: i1.XhrFactory }, { type: i2.NSFileSystem }, { type: ExcludedService }, { type: undefined, decorators: [{
                type: Optional
            }, {
                type: Inject,
                args: [HTTPS_REQUEST_DEFAULT_OPTIONS]
            }] }], null); })();

/** Page size injection token. */
const HTTPS_SSL_PINNING_OPTIONS = new InjectionToken('HTTPS_SSL_PINNING_OPTIONS');
class NativeScriptHttpsModule {
    constructor(defaults) {
        enableSSLPinning(defaults ?? { host: '', certificate: '' });
    }
    /**
     * Creates and configures a module.
     * @param defaults Https request default options.
     * @returns A wrapper around an NgModule that associates it with the providers.
     */
    static forRoot(defaults = { host: '', certificate: '' }) {
        return {
            ngModule: NativeScriptHttpsModule,
            providers: [
                { provide: HTTPS_REQUEST_DEFAULT_OPTIONS, useValue: defaults },
                { provide: HTTPS_SSL_PINNING_OPTIONS, useValue: defaults }
            ]
        };
    }
    static ɵfac = function NativeScriptHttpsModule_Factory(t) { return new (t || NativeScriptHttpsModule)(i0.ɵɵinject(HTTPS_SSL_PINNING_OPTIONS, 8)); };
    static ɵmod = /*@__PURE__*/ i0.ɵɵdefineNgModule({ type: NativeScriptHttpsModule });
    static ɵinj = /*@__PURE__*/ i0.ɵɵdefineInjector({ providers: [
            ExcludedService,
            NativeScriptHttpXhrBackend,
            { provide: HttpBackend, useExisting: NativeScriptHttpXhrBackend },
            { provide: HTTPS_REQUEST_DEFAULT_OPTIONS, useValue: {} },
            { provide: HTTPS_SSL_PINNING_OPTIONS, useValue: { host: '', certificate: '' } }
        ], imports: [NativeScriptHttpClientModule, NativeScriptHttpClientModule] });
}
(() => { (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassMetadata(NativeScriptHttpsModule, [{
        type: NgModule,
        args: [{
                providers: [
                    ExcludedService,
                    NativeScriptHttpXhrBackend,
                    { provide: HttpBackend, useExisting: NativeScriptHttpXhrBackend },
                    { provide: HTTPS_REQUEST_DEFAULT_OPTIONS, useValue: {} },
                    { provide: HTTPS_SSL_PINNING_OPTIONS, useValue: { host: '', certificate: '' } }
                ],
                imports: [NativeScriptHttpClientModule],
                exports: [NativeScriptHttpClientModule]
            }]
    }], () => [{ type: undefined, decorators: [{
                type: Optional
            }, {
                type: Inject,
                args: [HTTPS_SSL_PINNING_OPTIONS]
            }] }], null); })();
(function () { (typeof ngJitMode === "undefined" || ngJitMode) && i0.ɵɵsetNgModuleScope(NativeScriptHttpsModule, { imports: [NativeScriptHttpClientModule], exports: [NativeScriptHttpClientModule] }); })();

/**
 * Generated bundle index. Do not edit.
 */

export { HTTPS_REQUEST_DEFAULT_OPTIONS, HTTPS_SSL_PINNING_OPTIONS, NativeScriptHttpXhrBackend, NativeScriptHttpsModule };
//# sourceMappingURL=nativescript-community-https-angular.mjs.map
